package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.system.domain.SysPost;

/**
 * 岗位信息 服务层
 * 
 * @author ruoyi
 */
public interface ISysPostService
{
    /**
     * 查询岗位信息集合
     * 
     * @param post 岗位信息
     * @return 岗位列表
     */
    public List<SysPost> selectPostList(SysPost post);

    /**
     * 查询所有岗位
     * 
     * @return 岗位列表
     */
    public List<SysPost> selectPostAll();

    /**
     * 通过岗位ID查询岗位信息
     * 
     * @param postId 岗位ID
     * @return 角色对象信息
     */
    public SysPost selectPostById(Long postId);


    /**
     * 根据用户ID获取岗位选择框列表
     * 
     * @param userId 用户ID
     * @return 选中岗位ID列表
     */
    public List<Long> selectPostListByUserId(Long userId);

    /**
     * 校验岗位名称
     * 
     * @param post 岗位信息
     * @return 结果
     */
    public boolean checkPostNameUnique(SysPost post);

    /**
     * 校验岗位编码
     * 
     * @param post 岗位信息
     * @return 结果
     */
    public boolean checkPostCodeUnique(SysPost post);

    /**
     * 通过岗位ID查询岗位使用数量
     * 
     * @param postId 岗位ID
     * @return 结果
     */
    public int countUserPostById(Long postId);

    /**
     * 删除岗位信息
     * 
     * @param postId 岗位ID
     * @return 结果
     */
    public int deletePostById(Long postId);

    /**
     * 批量删除岗位信息
     * 
     * @param postIds 需要删除的岗位ID
     * @return 结果
     */
    public int deletePostByIds(Long[] postIds);

    /**
     * 新增保存岗位信息
     * 
     * @param post 岗位信息
     * @return 结果
     */
    public int insertPost(SysPost post);

    /**
     * 修改保存岗位信息
     * 
     * @param post 岗位信息
     * @return 结果
     */
    public int updatePost(SysPost post);

    /**
     * 查询高级管理员集合
     *
     * @param
     * @return 高级管理员列表
     */
    public List<SysUser> selectGmAssistant(SysUser user);

    /**
     * 查询经营主任集合
     *
     * @param
     * @return 经营主任列表
     */
    public List<SysUser> selectJyLeader(SysUser user);

    /**
     * 查询董事会秘书集合
     *
     * @param
     * @return 董事会秘书列表
     */
    public List<SysUser> selectDsSecretary(SysUser user);

    /**
     * 根据岗位查询用户
     *
     * @param
     * @return 用户列表
     */
    public List<SysUser> selectUserListByPostName(String postName);

    /**
     * 查询子公司执行董事
     *
     * @param
     * @return 查询子公司执行董事
     */
    public SysUser selectSubLeaderByUserId(String userId);

    /**
     * 查询子公司总经理
     *
     * @param
     * @return 查询子公司总经理
     */
    public SysUser selectSubGmByUserId(String userId);

    /**
     * 查询分公司经理
     *
     * @param
     * @return 查询分公司经理
     */
    public SysUser selectBranchLeaderByUserId(String userId);

    /**
     * 查询部门主任
     *
     * @param
     * @return 查询部门主任
     */
    public SysUser selectDeptLeaderByUserId(String userId);

    /**
     * 查询部门主任
     *
     * @param
     * @return 查询部门主任
     */
    public SysUser selectParentDeptLeaderByUserId(String userId);

    /**
     * 查询部门副主任
     *
     * @param
     * @return 查询部门副主任
     */
    public SysUser selectViceDeptLeaderByUserId(String userId);

    /**
     * 查询子公司执行董事
     *
     * @param
     * @return 查询子公司执行董事
     */
    public SysUser selectSubLeaderByDeptId(String deptId);

    /**
     * 查询子公司总经理
     *
     * @param
     * @return 查询子公司总经理
     */
    public SysUser selectSubGmByDeptId(String deptId);

    /**
     * 查询分公司经理
     *
     * @param
     * @return 查询分公司经理
     */
    public SysUser selectBranchLeaderByDeptId(String deptId);

    /**
     * 查询部门主任
     *
     * @param
     * @return 查询部门主任
     */
    public SysUser selectParentDeptLeaderByDeptId(String deptId);

    /**
     * 查询部门主任
     *
     * @param
     * @return 查询部门主任
     */
    public SysUser selectDeptLeaderByDeptId(String deptId);

    /**
     * 查询部门主任
     *
     * @param
     * @return 查询部门主任
     */
    public List<SysUser> selectDeptLeadersByDeptId(String deptId);

    /**
     * 查询部门副主任
     *
     * @param
     * @return 查询部门副主任
     */
    public SysUser selectViceDeptLeaderByDeptId(String deptId);

    /**
     * 查询部门副主任列表
     *
     * @param
     * @return 查询部门副主任列表
     */
    public List<SysUser> selectViceDeptLeaderListByDeptId(String deptId);
}
